@@ -115,53 +115,17 @@ mkdir -p /root/whp
 rsync -auzvp --exclude='web-files/' ./ /root/whp/
 echo "✓ Release files copied to /root/whp/"
 
-# Install pgAdmin 4
-echo "Installing pgAdmin 4..."
-dnf install -y https://ftp.postgresql.org/pub/pgadmin/pgadmin4/yum/pgadmin4-redhat-repo-2-1.noarch.rpm
-dnf install -y pgadmin4-web
-
-# Install required Python module for pgAdmin setup
-echo "Installing required Python modules for pgAdmin..."
-pip3 install typer
-
-# Configure pgAdmin 4
-echo "Configuring pgAdmin 4..."
-# Create config_local.py for pgAdmin
-cat > /usr/pgadmin4/web/config_local.py << 'EOF'
-import os
-LOG_FILE = '/var/log/pgadmin/pgadmin4.log'
-SQLITE_PATH = '/var/lib/pgadmin/pgadmin4.db'
-SESSION_DB_PATH = '/var/lib/pgadmin/sessions'
-STORAGE_DIR = '/var/lib/pgadmin/storage'
-SERVER_MODE = True
-EOF
-
-# Set up pgAdmin directories
-mkdir -p /var/lib/pgadmin
-mkdir -p /var/log/pgadmin
-chown -R root:root /var/lib/pgadmin
-chown -R root:root /var/log/pgadmin
-
-# Configure Apache for pgAdmin
-cat > /etc/httpd/conf.d/pgadmin4.conf << 'EOF'
-LoadModule wsgi_module modules/mod_wsgi_python3.so
-WSGIDaemonProcess pgadmin processes=1 threads=25 python-home=/usr/pgadmin4/venv
-WSGIScriptAlias /pgadmin4 /usr/pgadmin4/web/pgAdmin4.wsgi
-
-<Directory /usr/pgadmin4/web/>
-    WSGIProcessGroup pgadmin
-    WSGIApplicationGroup %{GLOBAL}
-    Require all granted
-</Directory>
-EOF
-
-# Run pgAdmin setup
-echo "Setting up pgAdmin 4 configuration..."
-PGADMIN_SETUP_EMAIL='admin@localhost' PGADMIN_SETUP_PASSWORD="$postgres_password" /usr/pgadmin4/bin/setup-web.sh --yes
-if [ $? -eq 0 ]; then
-    echo "✓ pgAdmin 4 setup completed successfully"
+# Download Adminer for database management
+echo "Installing Adminer for database management..."
+if ! wget -q -O /docker/whp/web/adminer.php "https://www.adminer.org/latest.php"; then
+    echo "⚠ Failed to download latest Adminer, trying alternative URL..."
+    if ! wget -q -O /docker/whp/web/adminer.php "https://github.com/vrana/adminer/releases/download/v4.8.1/adminer-4.8.1.php"; then
+        echo "⚠ Failed to download Adminer - database management interface may not work"
+    else
+        echo "✓ Adminer downloaded successfully (fallback version)"
+    fi
 else
-    echo "⚠ pgAdmin 4 setup failed - continuing anyway"
+    echo "✓ Adminer downloaded successfully (latest version)"
 fi
 
 # Install ProFTPD package (configuration happens after database setup)
@@ -635,7 +599,7 @@ echo "9. WordPress auto-updates are configured to run every 6 hours (2 AM, 8 AM,
 echo "10. WordPress security settings include comprehensive options: file editor blocking, XML-RPC protection, version hiding, security headers, and more"
 echo "11. WebSocket terminal server provides full terminal access to containers via the web interface"
 echo "12. PostgreSQL database server is running on port 5432 with root credentials stored in /root/.pgpass"
-echo "13. pgAdmin 4 is available at https://your-server/pgadmin4 for PostgreSQL management"
+echo "13. Adminer is available for PostgreSQL management via the WHP interface"
 echo ""
 echo "Troubleshooting:"
 echo "- Check logs in /var/log/httpd/ for Apache issues"
