@@ -25,7 +25,29 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                         $message = 'Database name can only contain letters, numbers, and underscores';
                         $message_type = 'danger';
                     } else {
-                        $result = $PgSQLMgmt->createDatabase($db_name, AUTH_USER);
+                        // Use the actual PostgreSQL user as owner
+                        $pg_owner = (AUTH_USER === 'root' || AUTH_USER === 'whp') ? 'postgres' : AUTH_USER . '_pg';
+                        
+                        // For non-root users, ensure PostgreSQL user exists
+                        if (AUTH_USER !== 'root' && AUTH_USER !== 'whp') {
+                            $userExists = $PgSQLMgmt->checkUserExists($pg_owner);
+                            if (!$userExists['exists']) {
+                                // Create PostgreSQL user if it doesn't exist
+                                $pgPassword = bin2hex(random_bytes(12));
+                                $createResult = $PgSQLMgmt->createPostgreSQLUserForSSO($pg_owner, $pgPassword);
+                                if ($createResult['status'] !== '0') {
+                                    $message = 'Error creating PostgreSQL user: ' . $createResult['msg'];
+                                    $message_type = 'danger';
+                                    break;
+                                }
+                                // Store password for SSO integration
+                                require_once('/docker/whp/web/libs/usermgmt.php');
+                                $UserMgmt = new usermgmt();
+                                $UserMgmt->setUserPostgreSQLPassword(AUTH_USER, $pgPassword);
+                            }
+                        }
+                        
+                        $result = $PgSQLMgmt->createDatabase($db_name, $pg_owner);
                         if ($result['status'] === '0') {
                             $message = 'PostgreSQL database created successfully: ' . $db_name;
                             $message_type = 'success';
@@ -242,14 +264,14 @@ if ($db_users_result['status'] === '0') {
         </div>
     </div>
     <div class="col-md-6">
-        <!-- pgAdmin Quick Access -->
+        <!-- Adminer Quick Access -->
         <div class="card mb-3">
             <div class="card-body text-center py-3">
                 <h6 class="card-title mb-2">
-                    <i class="fa fa-database text-success"></i> pgAdmin 4
+                    <i class="fa fa-database"></i> Adminer
                 </h6>
-                <a href="pgadmin-sso.php" class="btn btn-success btn-sm" target="_blank">
-                    <i class="fa fa-external-link"></i> Open pgAdmin
+                <a href="adminer-sso.php" class="btn btn-primary btn-sm" target="_blank">
+                    <i class="fa fa-external-link"></i> Open Adminer
                 </a>
                 <p class="text-muted mb-0 mt-2 small">Database management interface</p>
             </div>
